@@ -791,7 +791,7 @@ void Uic::createFormImpl( const TQDomElement &e )
 		TQString label = DomTool::readAttribute( n, "title", "", comment ).toString();
 		out << indent << "addPage( " << page << ", \"\" );" << endl;
 		trout << indent << "setTitle( " << page << ", " << trcall( label, comment ) << " );" << endl;
-		TQVariant def( FALSE, 0 );
+		TQVariant def( FALSE );
 		if ( DomTool::hasAttribute( n, "backEnabled" ) )
 		    out << indent << "setBackEnabled(" << page << "," << mkBool( DomTool::readAttribute( n, "backEnabled", def).toBool() ) << ");" << endl;
 		if ( DomTool::hasAttribute( n, "nextEnabled" ) )
